@@ -14,7 +14,8 @@ def smartprint(*argv, **kwargs):
     extracted_code = line_of_code[opening_bracket_location:closing_bracket_location]
 
     # additional test to make sure extra brackets do not wreck our code
-    extracted_code = extracted_code.replace("sprint", "").replace("smartprint", "").replace("prints","")
+    extracted_code = extracted_code.replace("sprint", "").replace("prints", "").\
+                            replace("smartprint","").replace("print","")
 
     if len(argv) == 1 and len(kwargs) == 0:
         if isinstance(argv[0], list):
